@@ -1,3 +1,5 @@
+import logging
+
 import requests
 import time
 from typing import Optional, List
@@ -17,15 +19,21 @@ from redasql.exceptions import (
 
 class ApiClient:
 
-    def __init__(self, redash_url: str, api_key: str, proxy: str = None, debug: bool = False):
+    def __init__(
+        self,
+        redash_url: str,
+        api_key: str,
+        proxy: str = None,
+        wait_interval_sec: float = 0,
+        timeout_count: Optional[int] = 600,
+        debug: bool = False
+    ):
         self.redash_url = redash_url.rstrip('/')
-        self.session = requests.Session()
-        self.session.headers.update({'Authorization': f'Key {api_key}'})
-        self.proxy = None
-        if proxy:
-            self.proxy = proxy
-        if self.proxy:
-            self.session.proxies.update({'http': self.proxy, 'https': self.proxy})
+        self.api_key = api_key
+        self.proxy = proxy
+        self._create_session(self.api_key, self.proxy)
+        self.wait_interval_sec = wait_interval_sec
+        self.timeout_count = timeout_count
         if debug:
             import logging
             import http.client as http_client
@@ -34,6 +42,17 @@ class ApiClient:
             fmt = "[DEBUG LOGGING][%(asctime)s] %(levelname)s %(name)s :%(message)s"
             logging.basicConfig(level=logging.DEBUG, format=fmt)
             http_client.HTTPConnection.debuglevel = 1
+        self._version: Optional[str] = None
+
+    @property
+    def version(self):
+        if not self._version:
+            self._version = self.get_version()
+        return self._version
+
+    @property
+    def major_version(self) -> int:
+        return int(self.version.split('.')[0])
 
     def get_data_sources(self) -> List[DataSourceResponse]:
         res = self._get('api/data_sources')
@@ -52,8 +71,20 @@ class ApiClient:
                 return ds
         raise DataSourceNotFoundError(f'data source id [{data_source_id}] is not found.')
 
-    def get_schema(self, data_source_id: int) -> List[SchemaResponse]:
-        res = self._get(f'api/data_sources/{data_source_id}/schema')
+    def get_schema(self, data_source_id: int, refresh: bool = True) -> List[SchemaResponse]:
+        param = ''
+        if refresh:
+            param = '?refresh=true'
+        res = self._get(f'api/data_sources/{data_source_id}/schema{param}')
+        res_json = res.json()
+        # over redash ver10 return job, when refresh = true.
+        if 'job' in res_json:
+            return self._wait_job_for_schema(
+                res_json['job']['id'],
+                timeout=self.timeout_count,
+                wait_interval_sec=self.wait_interval_sec
+            )
+
         if 'schema' not in res.json():
             return []
         return [SchemaResponse.from_response(s) for s in res.json()['schema']]
@@ -76,7 +107,7 @@ class ApiClient:
         return QueryResultResponse.from_response(res.json()['query_result'])
 
     def execute_query(
-            self, query: str, data_source_id: int, max_age: int = -1, timeout=10*60
+            self, query: str, data_source_id: int, max_age: int = -1
     ) -> QueryResultResponse:
         res = self._post(
             'api/query_results',
@@ -93,9 +124,15 @@ class ApiClient:
 
         # no result, wait execution.
         job_id = res_json['job']['id']
-        return self._wait_job(job_id, timeout)
+        return self._wait_job(job_id, self.timeout_count, self.wait_interval_sec)
 
-    def _wait_job(self, job_id: str, timeout: int):
+    def _create_session(self, api_key, proxy):
+        self.session = requests.Session()
+        self.session.headers.update({'Authorization': f'Key {api_key}'})
+        if proxy:
+            self.session.proxies.update({'http': self.proxy, 'https': self.proxy})
+
+    def _wait_job(self, job_id: str, timeout: int, wait_interval_sec: float):
         retry_counter = 0
         while True:
             res = self._get(f'api/jobs/{job_id}')
@@ -111,10 +148,30 @@ class ApiClient:
                 error_msg = res_json['job']['error']
                 raise QueryRuntimeError(error_msg)
 
+            time.sleep(wait_interval_sec)
             retry_counter += 1
             if retry_counter > timeout:
                 raise QueryTimeoutError(f'Wait Query Complete. but not completed[{timeout}].')
-            time.sleep(0.1)
+
+    def _wait_job_for_schema(self, job_id: str, timeout: int, wait_interval_sec: float):
+        retry_counter = 0
+        while True:
+            res = self._get(f'api/jobs/{job_id}')
+            res_json = res.json()
+
+            # 3: success
+            if res_json.get('job', {}).get('status') == 3:
+                schema_result = res_json['job']['result']
+                return [SchemaResponse.from_response(s) for s in schema_result]
+
+            # 4: error
+            if res_json.get('job', {}).get('status') == 4:
+                error_msg = res_json['job']['error']
+                raise QueryRuntimeError(error_msg)
+            time.sleep(wait_interval_sec)
+            retry_counter += 1
+            if retry_counter > timeout:
+                raise QueryTimeoutError(f'Wait Query Complete. but not completed[{timeout} * {wait_interval_sec}].')
 
     def _get(self, path, **kwargs):
         return self._request('GET', path, **kwargs)
@@ -124,6 +181,18 @@ class ApiClient:
 
     def _request(self, method, path, **kwargs):
         url = '{}/{}'.format(self.redash_url, path)
-        response = self.session.request(method, url, **kwargs)
-        response.raise_for_status()
-        return response
+        retry_count = 0
+        max_retry = 3
+        latest_error = None
+        while retry_count <= max_retry:
+            try:
+                response = self.session.request(method, url, **kwargs)
+                response.raise_for_status()
+                return response
+            except requests.exceptions.ConnectionError as e:
+                retry_count += 1
+                latest_error = e
+                logging.debug(f'reconnect[{retry_count}] because of [{e}]')
+                self._create_session(self.api_key, self.proxy)
+
+        raise latest_error
