@@ -3,7 +3,6 @@ import os
 import re
 import sys
 import pkg_resources
-from pyperclip import copy
 
 from textwrap import dedent
 from os.path import expanduser, exists
@@ -19,6 +18,7 @@ from redasql.dto import CommandArgs, DataSourceResponse
 from redasql.exceptions import RedasqlException, InsufficientParametersError, NoDataSourceError
 from redasql.metacommand_executor import meta_command_factory
 from redasql.result_formatter import formatter_factory
+from redasql.result_outputter import out_putter_factory
 from redasql.completer import RedasqlCompleter, CompleteData
 
 
@@ -34,6 +34,8 @@ class MainCommand:
         proxy: str,
         data_source_name: Optional[str],
         ignore_rc: bool,
+        wait_interval_sec: float,
+        timeout_count: int,
         debug: bool,
     ):
         self.endpoint = endpoint if endpoint else os.environ.get('REDASQL_REDASH_ENDPOINT')
@@ -50,10 +52,12 @@ class MainCommand:
             redash_url=self.endpoint,
             api_key=self.api_key,
             proxy=self.proxy,
+            wait_interval_sec=wait_interval_sec,
+            timeout_count=timeout_count,
             debug=debug,
         )
         self.pivoted = False
-        self.output = OutputType.STDOUT
+        self.output = out_putter_factory(OutputType.STDOUT)
         self.formatter = formatter_factory(FormatterType.TABLE)
         self.input_buffer = []
         self.complete_data = CompleteData()
@@ -161,18 +165,21 @@ class MainCommand:
             """))
             return
         formatted_string = self.formatter(query_result, self.pivoted).format()
-        print(formatted_string)
-        print(dedent(f"""
-        {query_result.rows_count_for_display}
-        {query_result.runtime_for_display}
-        """))
-        if self.output == OutputType.STDOUT_AND_CLIPBOARD:
-            copy(formatted_string)
+        self.output.output(
+            result_str=formatted_string,
+            query_result=query_result
+        )
 
     def execute_meta_command_handler(self, input_string):
         command, *args = re.split(r'\s+', input_string.strip())
         executor = meta_command_factory(command)
-        e = executor(self.client, self.data_source, self.pivoted, self.formatter, self.output)
+        e = executor(
+            self.client,
+            self.data_source,
+            self.pivoted,
+            self.formatter,
+            self.output,
+        )
         meta_command_return_list = e.exec(*args)
         if self.debug:
             print(command, args, meta_command_return_list)
@@ -256,6 +263,22 @@ def init():
         action='store_true',
         default=False,
     )
+    parser.add_argument(
+        '--wait-interval-sec',
+        help=dedent("""
+        Wait Job Pooling Interval Sec(float)
+        """),
+        type=float,
+        default=0.1,
+    )
+    parser.add_argument(
+        '--timeout-count',
+        help=dedent("""
+        Wait Job Pooling Count(int)
+        """),
+        type=int,
+        default=600,
+    )
     parser.add_argument(
         '--debug',
         help=dedent("""
@@ -270,6 +293,8 @@ def init():
         endpoint=args.server_host,
         data_source_name=args.data_source,
         proxy=args.proxy,
+        wait_interval_sec=args.wait_interval_sec,
+        timeout_count=args.timeout_count,
         ignore_rc=args.ignore_rc,
         debug=args.debug,
     )
