@@ -18,5 +18,17 @@ class InvalidMetaCommand(RedasqlException):
     """ invalid meta command"""
 
 
+class InvalidSettingError(RedasqlException):
+    """ invalid setting requested. """
+
+
 class InsufficientParametersError(RedasqlException):
     """ api key and endpoint must be set """
+
+
+class NoDataSourceError(RedasqlException):
+    """ not set datasource """
+
+
+class SqlFileNotFoundError(RedasqlException):
+    """ specified file is not exists. """
